<?php if ( ! defined( 'ABSPATH' ) ) { die; } // Cannot access directly.
/**
 *
 * Induxter Admin Pages
 *
 */
if ( ! class_exists( 'Induxter_Admin' ) ) {

  class Induxter_Admin{

    public static $item_id = '27318531';

    public static $api_url = 'https://api.themedraft.net/';

    private static $instance = null;

    public static function init() {
      if( is_null( self::$instance ) ) {
        self::$instance = new self();
      }
      return self::$instance;
    }

    public function __construct() {

      add_action( 'init', array( $this, 'induxter_create_tgmpa_page' ), 1 );
      add_action( 'admin_menu', array( $this, 'induxter_create_admin_page' ), 1 );
      add_action( 'admin_enqueue_scripts', array( $this, 'induxter_admin_page_enqueue_scripts' ) );
      
      add_filter( 'tgmpa_plugin_action_links', array( $this, 'induxter_tgmpa_plugin_action_links' ), 10, 3 );
      add_filter( 'pt-ocdi/plugin_page_setup', array( $this, 'induxter_pt_ocdi_page_setup' ) );
      add_filter( 'pt-ocdi/plugin_page_display_callback_function', array( $this, 'induxter_pt_ocdi_page_callback' ) );
    
    }

    public function induxter_create_admin_page() {
      add_menu_page( esc_html__( 'Induxter', 'induxter' ), esc_html__( 'Induxter', 'induxter' ), 'manage_options', 'induxter', array( $this, 'induxter_admin_page_dashboard' ), 'dashicons-screenoptions', 2 );
      add_submenu_page( 'induxter', esc_html__( 'Activation', 'induxter' ), esc_html__( 'Activation', 'induxter' ), 'manage_options', 'induxter', array( $this, 'induxter_admin_page_dashboard' ) );
    }

    public function induxter_admin_page_dashboard() {
      require_once INDUXTER_INC_DIR .'admin/page-dashboard.php';
    }

    public function induxter_create_tgmpa_page() {
      require_once INDUXTER_INC_DIR .'admin/class-tgm-plugin-activation.php';
      require_once INDUXTER_INC_DIR .'admin/page-tgmpa.php';
    }

    public function induxter_admin_page_enqueue_scripts() {
      wp_enqueue_style( 'induxter-admin', get_theme_file_uri( 'inc/admin/assets/css/admin.css' ), array(), INDUXTER_VERSION, 'all' );
    }

    public function induxter_pt_ocdi_page_setup( $args ) {

      $args['parent_slug'] = 'induxter';
      $args['menu_slug']   = 'induxter-import-demo';
      $args['menu_title']  = esc_html__( 'Import Demo', 'induxter' );
      $args['capability']  = 'manage_options';

      return $args;

    }

    public function induxter_pt_ocdi_page_callback( $callback ) {

      if ( ! self::induxter_is_registered() ) {
        return array( $this, 'induxter_pt_ocdi_plugin_page_license_notify' );
      }

      return $callback;

    }

    public function induxter_pt_ocdi_plugin_page_license_notify() {

      echo sprintf( '<p><a href="%s" class="td-tgmpa-notice"><i class="dashicons dashicons-lock"></i>%s</a></p>',
        esc_attr( add_query_arg( array( 'page' => 'induxter' ), admin_url( 'admin.php' ) ) ),
        esc_html__( 'Register to unlock.', 'induxter' )
      );
    
    }

    public function induxter_tgmpa_plugin_action_links( $actions, $slug, $item ) {

      if ( $item['server'] === 'api' && ! self::induxter_is_registered() ) {
        
        $actions['install'] = sprintf( '<a href="%s" class="td-tgmpa-notice"><i class="dashicons dashicons-lock"></i>%s</a>',
          esc_attr( add_query_arg( array( 'page' => 'induxter' ), admin_url( 'admin.php' ) ) ),
          esc_html__( 'Register to unlock.', 'induxter' )
        );
        
        unset( $actions['activate'] );
        unset( $actions['update'] );
      
      }

      return $actions;

    }

    public static function induxter_is_registered() {

      return ( ! empty( get_option( 'envato_purchase_code_'. self::$item_id ) ) ) ? true : false;

    }
    
  }

  Induxter_Admin::init();
}