<?php
// Create header Settings section
CSF::createSection($induxter_theme_option, array(
	'title' => esc_html__('Header Settings', 'induxter'),
	'id'    => 'header_options',
	'icon'  => 'fa fa-header',
));


CSF::createSection($induxter_theme_option, array(
	'parent' => 'header_options',
	'title'  => esc_html__('Header Options', 'induxter'),
	'icon'   => 'fa fa-credit-card',
	'fields' => array(
		array(
			'id'       => 'site_default_header',
			'type'     => 'image_select',
			'title'    => esc_html__('Header Style', 'induxter'),
			'options'  => array(
				'header-style-one'   => get_theme_file_uri('assets/images/header-one.png'),
				'header-style-two'   => get_theme_file_uri('assets/images/header-two.png'),
				'header-style-three' => get_theme_file_uri('assets/images/header-three.png'),
				'header-style-four'  => get_theme_file_uri('assets/images/header-four.png'),
				'header-style-five'  => get_theme_file_uri('assets/images/header-five.png'),
				'header-style-six'   => get_theme_file_uri('assets/images/header-six.png'),
				'header-style-seven' => get_theme_file_uri('assets/images/header-seven.png'),
			),
			'default'  => 'header-style-one',
			'subtitle' => esc_html__('Select site default header style. You can override this settings on individual page / Posts.', 'induxter'),
		),

		array(
			'id'      => 'header_content_layout',
			'type'    => 'button_set',
			'title'   => esc_html__('Header Layout', 'induxter'),
			'options' => array(
				'container'       => esc_html__('Box', 'induxter'),
				'container-fluid' => esc_html__('Full Width', 'induxter'),
			),
			'default' => 'container',
			'desc'    => esc_html__('Select header content layout.', 'induxter'),
		),

		array(
			'id'      => 'dropdown_indicator',
			'type'    => 'button_set',
			'title'   => esc_html__('Dropdown Indicator', 'induxter'),
			'options' => array(
				'plus'  => esc_html__('Plus', 'induxter'),
				'arrow' => esc_html__('Arrow', 'induxter'),
			),
			'default' => 'plus',
			'desc'    => esc_html__('Select dropdown indicator.', 'induxter'),
		),

		array(
			'id'       => 'sticky_header',
			'type'     => 'switcher',
			'title'    => esc_html__('Enable Sticky Header', 'induxter'),
			'default'  => true,
			'text_on'  => esc_html__('Yes', 'induxter'),
			'text_off' => esc_html__('No', 'induxter'),
			'desc'     => esc_html__('Enable / Disable sticky header.', 'induxter'),
		),

		array(
			'id'         => 'enable_header_cart',
			'type'       => 'switcher',
			'title'      => esc_html__('Enable Header Cart ', 'induxter'),
			'default'    => true,
			'text_on'    => esc_html__('Yes', 'induxter'),
			'text_off'   => esc_html__('No', 'induxter'),
			'desc'       => esc_html__('Show / Hide header cart icon.', 'induxter'),
			'dependency' => array('site_default_header', 'any', 'header-style-two,header-style-six,header-style-two,header-style-seven', 'all'),
		),

		array(
			'id'           => 'header_default_logo',
			'type'         => 'media',
			'title'        => esc_html__('Header Logo', 'induxter'),
			'library'      => 'image',
			'url'          => false,
			'button_title' => esc_html__('Upload Logo', 'induxter'),
			'desc'         => esc_html__('Upload logo image', 'induxter'),

		),

		array(
			'id'          => 'logo_maximum_width',
			'type'        => 'slider',
			'title'       => esc_html__('Logo Maximum Width', 'induxter'),
			'min'         => 50,
			'max'         => 500,
			'step'        => 1,
			'unit'        => 'px',
			'output'      => '.logo-wrap img,.about-info-img img',
			'output_mode' => 'max-width',
			'desc'        => esc_html__('Logo image maximum width', 'induxter'),
		),

		array(
			'id'         => 'header_cta_btn_text',
			'type'       => 'text',
			'title'      => esc_html__('Header CTA Button Text', 'induxter'),
			'default'    => esc_html__('Get a Quote', 'induxter'),
			'desc'       => esc_html__('Type header CTA button text here', 'induxter'),
			'dependency' => array('site_default_header', 'any', 'header-style-three,header-style-four,header-style-six,header-style-seven'),
		),

		array(
			'id'         => 'header_cta_btn_url',
			'type'       => 'text',
			'title'      => esc_html__('Header CTA Button Url', 'induxter'),
			'default'    => '#',
			'desc'       => esc_html__('Type header CTA button URL here', 'induxter'),
			'dependency' => array('site_default_header', 'any', 'header-style-three,header-style-four,header-style-six,header-style-seven'),
		),

		array(
			'id'         => 'enable_mobile_menu_cta_button',
			'type'       => 'switcher',
			'title'      => esc_html__('Enable CTA Button On Mobile Menu', 'induxter'),
			'default'    => false,
			'text_on'    => esc_html__('Yes', 'induxter'),
			'text_off'   => esc_html__('No', 'induxter'),
			'desc'       => esc_html__('Show / Hide CTA button on mobile menu', 'induxter'),
			'dependency' => array('site_default_header', 'any', 'header-style-three,header-style-four,header-style-six,header-style-seven'),
		),
	)
));

CSF::createSection($induxter_theme_option, array(
	'parent' => 'header_options',
	'title'  => esc_html__('Header Top', 'induxter'),
	'icon'   => 'fas fa-level-up-alt',
	'fields' => array(

		array(
			'type'       => 'notice',
			'style'      => 'info',
			'content'    => esc_html__('Header top not available with selected header style', 'induxter'),
			'dependency' => array('site_default_header', 'any', 'header-style-one', 'all'),
		),

		array(
			'id'         => 'enable_header_top',
			'type'       => 'switcher',
			'title'      => esc_html__('Enable Header Top', 'induxter'),
			'default'    => true,
			'text_on'    => esc_html__('Yes', 'induxter'),
			'text_off'   => esc_html__('No', 'induxter'),
			'desc'       => esc_html__('Enable / Disable header top info.', 'induxter'),
			'dependency' => array('site_default_header', 'any', 'header-style-two,header-style-three,header-style-four,header-style-five,header-style-six,header-style-seven', 'all'),
		),

		array(
			'id'           => 'header_top_info_text',
			'type'         => 'group',
			'title'        => esc_html__('Top Info Text', 'induxter'),
			'subtitle'     => esc_html__('Add / edit header top info text from here.', 'induxter'),
			'desc'         => esc_html__('Click "Add Info" button to add new Information.', 'induxter'),
			'button_title' => esc_html__('Add Info', 'induxter'),
			'fields'       => array(

				array(
					'id'            => 'info_text',
					'type'          => 'wp_editor',
					'media_buttons' => false,
					'height'        => '80px',
					'title'         => esc_html__('Info Text', 'induxter'),
					'desc'          => esc_html__('Type top left text here.', 'induxter'),
				),

				array(
					'id'         => 'info_subtitle',
					'type'       => 'text',
					'title'      => esc_html__('Subtitle', 'induxter'),
					'default'    => esc_html__('Call Us', 'induxter'),
					'dependency' => array('site_default_header|enable_header_top', 'any|==', 'header-style-seven|true', 'all|all'),

				),

				array(
					'id'    => 'info_icon',
					'type'  => 'icon',
					'title' => esc_html__('Icon', 'induxter'),
					'desc'  => esc_html__('Select icon', 'induxter'),
				),


			),
			'default'      => array(
				array(
					'info_text' => esc_html__('We work with global industries!', 'induxter'),
					'info_icon' => 'flaticon-industry-factory-10',
				),
			),

			'dependency' => array('site_default_header|enable_header_top', 'any|==', 'header-style-two,header-style-three,header-style-four,header-style-five,header-style-six,header-style-seven|true', 'all|all'),
		),

		array(
			'id'         => 'top_info_column',
			'type'       => 'select',
			'title'      => esc_html__('Top Info Column', 'induxter'),
			'options'    => array(
				''          => esc_html__('Select Column', 'induxter'),
				'col-lg-1'  => esc_html__('1 Column', 'induxter'),
				'col-lg-2'  => esc_html__('2 Column', 'induxter'),
				'col-lg-3'  => esc_html__('3 Column', 'induxter'),
				'col-lg-4'  => esc_html__('4 Column', 'induxter'),
				'col-lg-5'  => esc_html__('5 Column', 'induxter'),
				'col-lg-6'  => esc_html__('6 Column', 'induxter'),
				'col-lg-7'  => esc_html__('7 Column', 'induxter'),
				'col-lg-8'  => esc_html__('8 Column', 'induxter'),
				'col-lg-9'  => esc_html__('9 Column', 'induxter'),
				'col-lg-10' => esc_html__('10 Column', 'induxter'),
				'col-lg-11' => esc_html__('11 Column', 'induxter'),
				'col-lg-12' => esc_html__('12 Column', 'induxter'),
			),
			'default'    => '',
			'desc'       => esc_html__('Select top info column width', 'induxter'),
			'dependency' => array('site_default_header|enable_header_top', 'any|==', 'header-style-two,header-style-three,header-style-four,header-style-five,header-style-six,header-style-seven|true', 'all|all'),
		),

		array(
			'id'           => 'header_top_socials',
			'type'         => 'group',
			'title'        => esc_html__('Top Social Icons', 'induxter'),
			'subtitle'     => esc_html__('Add / edit top social icons from here.', 'induxter'),
			'desc'         => esc_html__('Click "Add Social Icon" button to add new icons.', 'induxter'),
			'button_title' => esc_html__('Add Social Icon', 'induxter'),
			'fields'       => array(

				array(
					'id'    => 'icon',
					'type'  => 'icon',
					'title' => esc_html__('Site Icon', 'induxter'),
					'desc'  => esc_html__('Select icon', 'induxter'),
				),

				array(
					'id'    => 'profile_url',
					'type'  => 'text',
					'title' => esc_html__('Profile Link', 'induxter'),
					'desc'  => esc_html__('Type social profile link here.', 'induxter'),
				),


			),

			'default' => array(
				array(
					'icon'        => 'fab fa-twitter',
					'profile_url' => '#',
				),
			),

			'dependency' => array('site_default_header|enable_header_top', 'any|==', 'header-style-two,header-style-three,header-style-four,header-style-five,header-style-six,header-style-seven|true', 'all|all'),
		),

		array(
			'id'      => 'top_social_column',
			'type'    => 'select',
			'title'   => esc_html__('Top Social Icon Column', 'induxter'),
			'options' => array(
				''  => esc_html__('Select Column', 'induxter'),
				'col-lg-1'  => esc_html__('1 Column', 'induxter'),
				'col-lg-2'  => esc_html__('2 Column', 'induxter'),
				'col-lg-3'  => esc_html__('3 Column', 'induxter'),
				'col-lg-4'  => esc_html__('4 Column', 'induxter'),
				'col-lg-5'  => esc_html__('5 Column', 'induxter'),
				'col-lg-6'  => esc_html__('6 Column', 'induxter'),
				'col-lg-7'  => esc_html__('7 Column', 'induxter'),
				'col-lg-8'  => esc_html__('8 Column', 'induxter'),
				'col-lg-9'  => esc_html__('9 Column', 'induxter'),
				'col-lg-10'  => esc_html__('10 Column', 'induxter'),
				'col-lg-11'  => esc_html__('11 Column', 'induxter'),
				'col-lg-12'  => esc_html__('12 Column', 'induxter'),
			),
			'default' => '',
			'desc'    => esc_html__('Select top social icon column width', 'induxter'),
			'dependency' => array('site_default_header|enable_header_top', 'any|==', 'header-style-two,header-style-three,header-style-four,header-style-five,header-style-six,header-style-seven|true', 'all|all'),
		),
	)
));

// Header Color

CSF::createSection($induxter_theme_option, array(
	'parent' => 'header_options',
	'title'  => esc_html__('Header Colors', 'induxter'),
	'icon'   => 'fas fa-paint-brush',
	'fields' => array(

		array(
			'id'          => 'header_top_bg_color',
			'type'        => 'color',
			'title'       => esc_html__('Top Background Color', 'induxter'),
			'desc'        => esc_html__('Select header top background color.', 'induxter'),
			'dependency'  => array('site_default_header|enable_header_top', 'any|==', 'header-style-two,header-style-three,header-style-four,header-style-five,header-style-six,header-style-seven|true', 'all|all'),
			'output'      => '.header-top-area,.header-style-three .header-top-area,.header-style-four .header-top-area,.header-style-seven .header-top-area',
			'output_mode' => 'background-color'
		),

		array(
			'id'         => 'header_top_text_color',
			'type'       => 'color',
			'title'      => esc_html__('Top Text Color', 'induxter'),
			'desc'       => esc_html__('Select header top text color.', 'induxter'),
			'dependency' => array('site_default_header|enable_header_top', 'any|==', 'header-style-two,header-style-three,header-style-four,header-style-five,header-style-six,header-style-seven|true', 'all|all'),
			'output'     => array(
				'color'        => '.header-top-area li, .header-top-area li a,.header-style-four .header-top-area li, .header-style-four .header-top-area li a,.header-style-four .header-top-area .top-info-column li i,.header-style-four li.top-social-item a:hover,.header-style-seven .header-top-area li,.header-style-seven .header-top-area li a',

				'border-color' => 'li.top-social-item a,.header-style-four li.top-social-item a',
			),
		),

		array(
			'id'         => 'header_top_text_hover_color',
			'type'       => 'color',
			'title'      => esc_html__('Top Text Hover Color', 'induxter'),
			'desc'       => esc_html__('Select header top text hover color.', 'induxter'),
			'dependency' => array('site_default_header|enable_header_top', 'any|==', 'header-style-two,header-style-three,header-style-four,header-style-five,header-style-six,header-style-seven|true', 'all|all'),
			'output'     => array(
				'color'            => '.header-top-area li a:hover,.header-style-four .header-top-area .top-info-column li a:hover',
				'border-color'     => 'li.top-social-item a:hover,.header-style-four li.top-social-item a:hover,.header-style-four.home-banner-three .header-top-area li.top-social-item a:hover',
				'background-color' => '.header-style-four li.top-social-item a:hover',
			),
		),

		array(
			'id'         => 'header_top_icon_subtitle_color',
			'type'       => 'color',
			'title'      => esc_html__('Top Icon & Subtitle Color', 'induxter'),
			'desc'       => esc_html__('Select header top icon & subtitle text color.', 'induxter'),
			'dependency' => array('site_default_header|enable_header_top', 'any|==', 'header-style-seven|true', 'all|all'),
			'output'     => array(
				'color'        => '.header-style-seven .info-subtitle,.header-style-seven .top-info-item i,.header-style-seven li.top-social-item a',

				'background-color' => '.header-style-seven li.top-social-item a:hover',

				'border-color' => '.header-style-seven li.top-social-item a',
			),
		),

		array(
			'id'     => 'logo_bg_color',
			'type'   => 'color',
			'title'  => esc_html__('Logo Background Color', 'induxter'),
			'desc'   => esc_html__('Select logo background color.', 'induxter'),
			'output' => array(
				'background-color' => '.header-style-two .logo-column:before,.header-style-seven .site-branding',
			),
			'dependency' => array('site_default_header', 'any', 'header-style-two,header-style-five,header-style-six,header-style-seven', 'all'),
		),

		array(
			'id'     => 'menu_area_bg_color',
			'type'   => 'color',
			'title'  => esc_html__('Menu Background Color', 'induxter'),
			'desc'   => esc_html__('Select menu area background color.', 'induxter'),
			'output' => array(
				'color'            => 'a.td-header-cart-url .cart-product-count',
				'background-color' => '.header-style-two .main-menu-area,.header-style-three .header-navigation-area,.header-style-four .main-navigation:before,.header-style-four .main-menu-area,.header-style-three .main-menu-area.uk-active,.header-style-seven .logo-and-menu',
			),
		),

		array(
			'id'     => 'menu_area_text_color',
			'type'   => 'color',
			'title'  => esc_html__('Menu Text Color', 'induxter'),
			'desc'   => esc_html__('Select menu area text color.', 'induxter'),
			'output' => array(
				'color' => '.header-style-two .main-navigation ul li a, .header-style-two .main-navigation ul li a:hover, .header-style-two .main-navigation ul li.current-menu-item > a, .header-style-two .main-navigation ul li.current_page_item > a, .header-style-two .main-navigation ul li.current-menu-ancestor > a, .header-style-two .main-navigation ul li.current_page_ancestor > a,li.header-mini-cart i.fa,.main-navigation ul li a,.header-style-four .main-navigation ul li a,.td-header-src-btn,.header-style-seven .main-navigation ul li a,.header-style-seven .header-cta-button a',

				'background-color' => 'a.td-header-cart-url .cart-product-count,.header-style-two .main-navigation ul li a:after, .header-style-four .main-navigation ul li a:after,li.header-mini-cart:before,.mobile-menu-trigger span,.header-style-two .mobile-menu-trigger span,.header-style-four .mobile-menu-trigger span,.header-style-seven .mobile-menu-trigger span',
			),
		),

		array(
			'id'     => 'menu_area_text_hover_color',
			'type'   => 'color',
			'title'  => esc_html__('Menu Text Hover Color', 'induxter'),
			'desc'   => esc_html__('Select menu area text hover color.', 'induxter'),
			'output' => array(
				'color' => '.main-navigation ul li a:hover,.main-navigation ul li.current-menu-item > a,.main-navigation ul li.current-menu-ancestor > a, .main-navigation ul li.current_page_ancestor > a,.header-style-two .main-navigation ul li a:hover,.header-style-two .main-navigation ul li.current-menu-item > a, .header-style-two .main-navigation ul li.current_page_item > a, .header-style-two .main-navigation ul li.current-menu-ancestor > a, .header-style-two .main-navigation ul li.current_page_ancestor > a,.header-style-four .main-navigation ul li a:hover,.header-style-four .main-navigation ul li.current-menu-item > a,.header-style-four .main-navigation ul li.current-menu-ancestor > a, .header-style-four .main-navigation ul li.current_page_ancestor > a,.header-style-seven .main-navigation ul li a:hover, .header-style-seven .main-navigation ul li.current-menu-item > a, .header-style-seven .main-navigation ul li.current_page_item > a, .header-style-seven .main-navigation ul li.current-menu-ancestor > a, .header-style-seven .main-navigation ul li.current_page_ancestor > a,.header-style-seven .header-cta-button a:hover',

				'background-color' => '.header-style-three .main-navigation ul li a:after,.header-style-two .main-navigation ul li a:after,.header-style-four .main-navigation ul li a:after, .header-style-four .main-navigation ul li a:hover:after',
			),
		),

		array(
			'id'     => 'dropdown_menu_bg_color',
			'type'   => 'color',
			'title'  => esc_html__('Dropdown Background Color', 'induxter'),
			'desc'   => esc_html__('Select dropdown menu background color.', 'induxter'),
			'output' => array(
				'background-color' => '.main-navigation ul li ul',
			),
		),

		array(
			'id'     => 'dropdown_menu_text_color',
			'type'   => 'color',
			'title'  => esc_html__('Dropdown Text Color', 'induxter'),
			'desc'   => esc_html__('Select dropdown menu text color.', 'induxter'),
			'output' => array(
				'color' => '.main-navigation ul li ul li a,.header-style-two .main-navigation ul li ul li a,.header-style-four .main-navigation ul ul li a,.header-style-seven .main-navigation ul li ul li a',
			),
		),

		array(
			'id'     => 'dropdown_menu_text_hover_color',
			'type'   => 'color',
			'title'  => esc_html__('Dropdown Text Hover Color', 'induxter'),
			'desc'   => esc_html__('Select dropdown menu text color.', 'induxter'),
			'output' => array(
				'color' => '.main-navigation ul li ul li a:hover, .main-navigation ul li ul li.current-menu-item > a, .main-navigation ul li ul li.current-menu-ancestor > a, .main-navigation ul li ul li.current_page_ancestor > a,.header-style-two .main-navigation ul li ul li a:hover,.header-style-two .main-navigation ul li ul li.current-menu-item > a,.header-style-two .main-navigation ul li ul li.current_page_item > a,.header-style-two .main-navigation ul li ul li.current-menu-ancestor > a,.header-style-two .main-navigation ul li ul li.current_page_ancestor > a,.header-style-four .main-navigation ul ul li a:hover,.header-style-four .main-navigation ul ul li.current-menu-item > a,.header-style-four .main-navigation ul ul li.current_page_item > a,.header-style-four .main-navigation ul ul li.current-menu-ancestor > a,.header-style-four .main-navigation ul ul li.current_page_ancestor > a,.header-style-seven .main-navigation ul li ul li a:hover,.header-style-seven .main-navigation ul li ul li.current-menu-item > a, .header-style-seven .main-navigation ul li ul li.current_page_item > a, .header-style-seven .main-navigation ul li ul li.current-menu-ancestor > a, .header-style-seven .main-navigation ul li ul li.current_page_ancestor > a',
			),
		),

		array(
			'id'     => 'dropdown_menu_border_color',
			'type'   => 'color',
			'title'  => esc_html__('Dropdown Border Color', 'induxter'),
			'desc'   => esc_html__('Select dropdown menu background color.', 'induxter'),
			'output' => array(
				'border-color' => '.main-navigation ul li ul li',
			),
		),

		array(
			'id'         => 'header_btn_bg_color',
			'type'       => 'color',
			'title'      => esc_html__('Button Background Color', 'induxter'),
			'desc'       => esc_html__('Select header button background color.', 'induxter'),
			'dependency' => array('site_default_header', 'any', 'header-style-three,header-style-four', 'all'),
			'output'     => array(
				'background-color' => '.header-style-three .header-cta-button a,.header-style-four.home-banner-three .header-cta-button a',
			),
		),

		array(
			'id'     => 'mobile_menu_bg_color',
			'type'   => 'color',
			'title'  => esc_html__('Mobile Menu Background Color', 'induxter'),
			'desc'   => esc_html__('Select mobile menu background color.', 'induxter'),
			'output' => array(
				'background-color' => '.mobile-menu-container',
			),
		),

		array(
			'id'     => 'mobile_menu_text_color',
			'type'   => 'color',
			'title'  => esc_html__('Mobile Menu Text Color', 'induxter'),
			'desc'   => esc_html__('Select mobile menu text color.', 'induxter'),
			'output' => array(
				'color'            => '.slicknav_nav a, .slicknav_row a',
				'background-color' => '.mobile-menu-close::before, .mobile-menu-close::after',
			),
		),

		array(
			'id'     => 'mobile_menu_active_text_color',
			'type'   => 'color',
			'title'  => esc_html__('Mobile Menu Active Text Color', 'induxter'),
			'desc'   => esc_html__('Select mobile menu active text color.', 'induxter'),
			'output' => array(
				'color' => '.slicknav_nav a:hover, .slicknav_item.slicknav_row:hover a, .slicknav_item.slicknav_row:hover .slicknav_arrow, .slicknav_menu .current-menu-item > a, .slicknav_menu .current-menu-item .slicknav_row > a, .slicknav_menu .current-menu-ancestor > a, .slicknav_menu .current-menu-ancestor > .slicknav_row > a, .current-menu-ancestor > .slicknav_row .slicknav_arrow, .current-menu-item .slicknav_row .slicknav_arrow',
			),
		),

		array(
			'id'     => 'mobile_menu_bottom_border_color',
			'type'   => 'color',
			'title'  => esc_html__('Mobile Menu border Color', 'induxter'),
			'desc'   => esc_html__('Select mobile menu border color.', 'induxter'),
			'output' => array(
				'border-bottom-color' => '.slicknav_nav li a',
			),
		),

		array(
			'id'     => 'header_button_bg_color',
			'type'   => 'color',
			'title'  => esc_html__('Button Background Color', 'induxter'),
			'desc'   => esc_html__('Select button background color.', 'induxter'),
			'output' => array(
				'background-color' => '.header-style-three .header-cta-button a,.header-style-four.home-banner-three .header-cta-button a,.header-style-six .header-cta-button a,.header-style-seven .header-cta-button a',
			),
			'dependency' => array('site_default_header', 'any', 'header-style-three,header-style-four,header-style-six,header-style-seven', 'all'),
		),

		array(
			'id'     => 'header_button_text_color',
			'type'   => 'color',
			'title'  => esc_html__('Button Text Color', 'induxter'),
			'desc'   => esc_html__('Select button text color.', 'induxter'),
			'output' => array(
				'color' => '.header-style-three .header-cta-button a,.header-style-four.home-banner-three .header-cta-button a,.header-style-six .header-cta-button a,.header-style-seven .header-cta-button a',
			),
			'dependency' => array('site_default_header', 'any', 'header-style-three,header-style-four,header-style-six,header-style-seven', 'all'),
		),

		array(
			'id'     => 'header_button_bg_color_on_hover',
			'type'   => 'color',
			'title'  => esc_html__('Button Hover Background Color', 'induxter'),
			'desc'   => esc_html__('Select button hover background color.', 'induxter'),
			'output' => array(
				'background-color' => '.header-style-three .header-cta-button a:hover,.header-style-four.home-banner-three .header-cta-button a:hover,.header-style-six .header-cta-button a:hover,.header-style-seven .header-cta-button a:hover',
			),
			'dependency' => array('site_default_header', 'any', 'header-style-three,header-style-four,header-style-six,header-style-seven', 'all'),
		),

		array(
			'id'     => 'header_button_text_color_on_hover',
			'type'   => 'color',
			'title'  => esc_html__('Button Hover Text Color', 'induxter'),
			'desc'   => esc_html__('Select button hover text color.', 'induxter'),
			'output' => array(
				'color' => '.header-style-three .header-cta-button a:hover,.header-style-four.home-banner-three .header-cta-button a:hover,.header-style-six .header-cta-button a:hover,.header-style-seven .header-cta-button a:hover',
			),
			'dependency' => array('site_default_header', 'any', 'header-style-three,header-style-four,header-style-six,header-style-seven', 'all'),
		),
	)
));