<?php

if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly
}

/*
 *  Create theme options
 */

$induxter_theme_option = 'induxter_theme_options';

CSF::createOptions($induxter_theme_option, array(
	'framework_title' => wp_kses(
		sprintf(__("Induxter Options <small>V %s</small>", 'induxter'), $induxter_theme_data->get('Version')),
		array('small' => array())
	),
	'menu_title'      => esc_html__('Theme Options', 'induxter'),
	'menu_slug'       => 'induxter-options',
	'menu_type'       => 'submenu',
	'menu_parent'     => 'induxter',
	'class'           => 'induxter-theme-option-wrapper',
	'footer_credit'      => wp_kses(
		__( 'Developed by: <a target="_blank" href="https://themedraft.net">ThemeDraft</a>', 'induxter' ),
		array(
			'a'      => array(
				'href'   => array(),
				'target' => array()
			),
		)
	),
	'async_webfont' => false,
	'defaults'        => induxter_default_theme_options(),
	'footer_text'      => '',
));

/*
 * General options
 */
require_once 'general-options.php';

/*
 * Typography options
 */
require_once 'typography-options.php';

/*
 * Header options
 */
require_once 'header-options.php';

/*
 * Banner Options
 */
require_once 'banner-options.php';

/*
 * Page Options
 */
require_once 'page-options.php';

/*
 * Blog Page Options
 */
require_once 'blog-page-options.php';

/*
 * Single Post Options
 */
require_once 'single-post-options.php';

/*
 * Service Options
 */
require_once 'service-options.php';

/*
 * Team Options
 */
require_once 'team-options.php';

/*
 * Project Options
 */
require_once 'project-options.php';

/*
 * WooCommerce Options
 */
if ( class_exists( 'WooCommerce' ) ) {
	require_once 'woocommerce-options/woocommerce-options.php';
}

/*
 * Archive Page Options
 */
require_once 'archive-page-options.php';

/*
 * Search Page Options
 */
require_once 'search-page-options.php';


/*
 * Error 404 Page Options
 */
require_once 'error-page-options.php';

/*
 * Footer Options
 */
require_once 'footer-options.php';


/*
 * Elementor Widgets Options
 */
require_once 'elementor-widgets-options.php';

// Custom Css section
CSF::createSection( $induxter_theme_option, array(
	'title'  => esc_html__( 'Custom CSS & JS', 'induxter' ),
	'id'     => 'custom_css_options',
	'icon'   => 'fa fa-css3',
	'fields' => array(

		array(
			'id'       => 'induxter_custom_css',
			'type'     => 'code_editor',
			'title'    => esc_html__( 'Custom CSS', 'induxter' ),
			'settings' => array(
				'theme'  => 'mbo',
				'mode'   => 'css',
			),
			'sanitize' => false,
		),

		array(
			'id'       => 'induxter_header_script',
			'type'     => 'code_editor',
			'title'    => esc_html__('Header Scripts','induxter'),
			'settings' => array(
				'theme'  => 'monokai',
				'mode'   => 'javascript',
			),
			'sanitize' => false,
			'desc' => esc_html__( 'This scripts will be printed in the <head> section. Please use inside <script></script> tag.', 'induxter' ),
		),

		array(
			'id'       => 'induxter_footer_script',
			'type'     => 'code_editor',
			'title'    => esc_html__('Footer Scripts','induxter'),
			'settings' => array(
				'theme'  => 'monokai',
				'mode'   => 'javascript',
			),
			'sanitize' => false,
			'desc' => esc_html__( 'This scripts will be printed in the </body> section. Please use inside <script></script> tag.', 'induxter' ),
		),
	)
) );


/*
 * Backup options
 */
CSF::createSection($induxter_theme_option, array(
	'title'  => esc_html__('Backup', 'induxter'),
	'id'     => 'backup_options',
	'icon'   => 'fa fa-window-restore',
	'fields' => array(
		array(
			'type' => 'backup',
		),
	)
));